# This file is encoded in ShiftJIS.
die "This file is not encoded in ShiftJIS.\n" if q{} ne "\x82\xa0";

use Sjis;

# Search pattern not terminated
# uT[`p^[IȂv
eval { /\/ };
if ($@) {
    print 0;
}
else {
    print 1;
}

__END__

Sjis.pm ŏXNvg̎sʂȉɂȂ邱Ƃ҂Ă

1

Shift-JISeLXg𐳂
http://homepage1.nifty.com/nomenclator/perl/shiftjis.htm
